==> CGAL-5.2.2-doc_html.tar.xz: doc_html/Surface_mesh_topology/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2.2 - Surface Mesh Topology", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#SMTopology", [
        [ "Shortest Non-Contractible Curve", "index.html#SMTopology_shortest", null ],
        [ "Homotopy Test", "index.html#SMTopology_homotopy", null ]
      ] ],
      [ "API Description", "index.html#SMTopology_HowToUse", [
        [ "Specifying the Input Surface and Curves", "index.html#SMTopology_Input", null ],
        [ "Polygonal Schema Helper", "index.html#SMTopology_Schema", [
          [ "Polygonal Schema", "index.html#SMTopology_PL", null ],
          [ "Polygonal Schema with Boundary", "index.html#SMTopology_PL_with_Boundary", null ],
          [ "Curves on Polygonal Schema", "index.html#SMTopology_Curves_on_PS", null ]
        ] ],
        [ "Compute Shortest Non-contractible Cycle", "index.html#SMTopology_Compute_SNC", null ],
        [ "Compute Face Width", "index.html#SMTopology_Compute_facewidth", null ],
        [ "Testing Homotopy", "index.html#SMTopology_Queries", null ]
      ] ],
      [ "Examples", "index.html#SMTopology_Examples", [
        [ "Compute Shortest Non-contractible Cycle", "index.html#SMTopology_Example_I_II_III", null ],
        [ "Compute Face Width", "index.html#SMTopology_Example_IV", null ],
        [ "Basic Homotopy Test", "index.html#SMTopology_Example_V", null ],
        [ "Polygonal Schema", "index.html#SMTopology_Example_VI_VII", null ],
        [ "Open Path", "index.html#SMTopology_Example_VIII", null ]
      ] ],
      [ "Benchmarks", "index.html#SMTopology_Benchmarks", [
        [ "Combinatorial Surface Topology Computation Time", "index.html#SMTopology_bench1", null ],
        [ "Path Homotopy Tests", "index.html#SMTopology_bench2", null ]
      ] ],
      [ "Implementation Details", "index.html#SMTopology_Theory", [
        [ "Compute Shortest Non-Contractible Cycle", "index.html#SMTopology_SNC", null ],
        [ "Compute Face Width", "index.html#SMTopology_Facewidth", null ],
        [ "Reducing to a Quadrangulation", "index.html#SMTopology_Quad_System", null ],
        [ "Canonical Form", "index.html#SMTopology_Canonical", null ],
        [ "Homotopy Test", "index.html#SMTopology_Homotopy_Test", null ]
      ] ],
      [ "History", "index.html#Implementation", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Surface_mesh_topology_2edgewidth_surface_mesh_8cpp-example.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/Surface_mesh_topology/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.4.1 - Surface Mesh Topology", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#SMTopology", [
        [ "Shortest Non-Contractible Curve", "index.html#SMTopology_shortest", null ],
        [ "Homotopy Test", "index.html#SMTopology_homotopy", null ],
        [ "Simplicity Test", "index.html#SMTopology_simplicity", null ]
      ] ],
      [ "API Description", "index.html#SMTopology_HowToUse", [
        [ "Specifying the Input Surface and Curves", "index.html#SMTopology_Input", null ],
        [ "Polygonal Schema Helper", "index.html#SMTopology_Schema", [
          [ "Polygonal Schema", "index.html#SMTopology_PL", null ],
          [ "Polygonal Schema with Boundary", "index.html#SMTopology_PL_with_Boundary", null ],
          [ "Curves on Polygonal Schema", "index.html#SMTopology_Curves_on_PS", null ]
        ] ],
        [ "Compute Shortest Non-contractible Cycle", "index.html#SMTopology_Compute_SNC", null ],
        [ "Compute Face Width", "index.html#SMTopology_Compute_facewidth", null ],
        [ "Testing Homotopy", "index.html#SMTopology_Queries", null ],
        [ "Testing Simplicity", "index.html#SMTopology_Query_Simplicity", null ]
      ] ],
      [ "Examples", "index.html#SMTopology_Examples", [
        [ "Compute Shortest Non-contractible Cycle", "index.html#SMTopology_Example_I_II_III", null ],
        [ "Compute Face Width", "index.html#SMTopology_Example_IV", null ],
        [ "Basic Homotopy Test", "index.html#SMTopology_Example_V", null ],
        [ "Basic Simplicity Test", "index.html#SMTopology_Example_VI", null ],
        [ "Polygonal Schema", "index.html#SMTopology_Example_VI_VII", null ],
        [ "Open Path", "index.html#SMTopology_Example_VIII", null ]
      ] ],
      [ "Benchmarks", "index.html#SMTopology_Benchmarks", [
        [ "Combinatorial Surface Topology Computation Time", "index.html#SMTopology_bench1", null ],
        [ "Path Homotopy Tests", "index.html#SMTopology_bench2", null ]
      ] ],
      [ "Implementation Details", "index.html#SMTopology_Theory", [
        [ "Compute Shortest Non-Contractible Cycle", "index.html#SMTopology_SNC", null ],
        [ "Compute Face Width", "index.html#SMTopology_Facewidth", null ],
        [ "Reducing to a Quadrangulation", "index.html#SMTopology_Quad_System", null ],
        [ "Canonical Form", "index.html#SMTopology_Canonical", null ],
        [ "Homotopy Test", "index.html#SMTopology_Homotopy_Test", null ],
        [ "Simplicity Test", "index.html#SMTopology_Simplicity_Test", [
          [ "Detect Repetition", "index.html#SMTopology_Simplicity_Test_Primitive", null ],
          [ "Avoid Crossing by Switching", "index.html#SMTopology_Simplicity_Test_Switch", null ],
          [ "Decide Relative Order", "index.html#SMTopology_Simplicity_Test_Relative_Order", null ],
          [ "Verify Ordering", "index.html#SMTopology_Simplicity_Test_Verification", null ]
        ] ]
      ] ],
      [ "History", "index.html#Implementation", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Surface_mesh_topology_2edgewidth_surface_mesh_8cpp-example.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
